"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultForbiddenResponse = exports.executableOpenAPIMiddlewareSecurity = void 0;
const validation_1 = require("./validation");
/**
 * Will create a middleware that validates the incoming request
 * against document's and operations security requirements.
 *
 * If the request does not meet the security requirements, the
 * middleware will directly return a 403 response. This behavior
 * is overidable with `forbiddenResponse` option.
 */
const executableOpenAPIMiddlewareSecurity = ({ forbiddenResponse = exports.defaultForbiddenResponse } = {}) => {
    return (handle, paramters, body, context, info) => __awaiter(void 0, void 0, void 0, function* () {
        const { operationObject, document, executionRequest } = info;
        // Security at operation level overrides global security
        // https://github.com/OAI/OpenAPI-Specification/blob/main/versions/3.1.0.md#fixed-fields
        const security = operationObject.security !== undefined ? operationObject.security : document.security;
        if (security === undefined) {
            return yield handle(paramters, body, context, info);
        }
        const [pass, schemeResults] = validation_1.validateSecurity(security, executionRequest);
        if (!pass) {
            return yield forbiddenResponse(schemeResults, paramters, body, context, info);
        }
        return yield handle(paramters, body, context, info);
    });
};
exports.executableOpenAPIMiddlewareSecurity = executableOpenAPIMiddlewareSecurity;
const defaultForbiddenResponse = () => ({
    status: 403
});
exports.defaultForbiddenResponse = defaultForbiddenResponse;
//# sourceMappingURL=middleware.js.map