"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateSecurity = void 0;
/**
 * Implements security requirements validation logic.
 */
const validateSecurity = (security, request) => {
    const schemeResults = {};
    // Only one of the security requirement objects need to be satisfied to authorize a request
    const pass = security.some((securityRequirement) => {
        // empty security requirement => optional => pass
        if (Object.keys(securityRequirement).length === 0)
            return true;
        // all schemes MUST be satisfied for a request to be authorized
        return Object.entries(securityRequirement).every(([securitySchemeName, scopes]) => {
            var _a;
            const requestSecurityForThisScheme = (_a = request.securities) === null || _a === void 0 ? void 0 : _a[securitySchemeName];
            // no entry in request's securities
            if (requestSecurityForThisScheme === false || requestSecurityForThisScheme === undefined) {
                schemeResults[securitySchemeName] = 'required but request not authorized';
                return false;
            }
            const requestScopes = Array.isArray(requestSecurityForThisScheme) ? requestSecurityForThisScheme : [];
            // no scopes required
            if (scopes.length === 0) {
                return true;
            }
            // should match required scopes
            const missingScopes = scopes.filter((scope) => !requestScopes.includes(scope));
            if (missingScopes.length === 0) {
                return true;
            }
            schemeResults[securitySchemeName] = `required scopes are missing: ${missingScopes.join(',')}`;
            return false;
        });
    });
    return [pass, schemeResults];
};
exports.validateSecurity = validateSecurity;
//# sourceMappingURL=validation.js.map